==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/controllers/top_controller.rb <==
# -*- coding: utf-8 -*-
class TopController < ApplicationController  
  class_desc :display_name => "トップページ"

  desc :invisible => true, :auth => :user_login
  def index
    #ダッシュボードの表示権限がある場合はdashboardを表示する
    if Goldberg.action_authorised?('top', 'dashboard')
      dashboard
      return
    end
    
    render(:index)
  end
  
  desc :invisible => true, :auth => :user_login
  def action_authorised?
    logged_in?
  end
  
  # ダッシュボードを表示する
  desc :display_name => "ダッシュボード", :category_name => :index
  def dashboard
    #ダッシュボードの表示権限が無い場合はindexを表示する
    unless Goldberg.action_authorised?('top', 'dashboard')
      render(:index)
      return
    end
    
    #注文
    @order_counts = Order.count(:include => :order_shippings, :conditions => ['(test_flg IS NULL OR test_flg = 0)'], :group => 'order_shippings.status_div')
    #注文(特記事項あり)
    @order_comment_counts = Order.count(:include => :order_shippings, 
      :conditions => ["(test_flg IS NULL OR test_flg = 0) AND (free_request IS NOT NULL AND free_request != '')"], :group => 'order_shippings.status_div')
    #問い合わせ
    @inquiry_count = Inquiry.count(:conditions => ["(test_flg IS NULL OR test_flg = 0) AND status_div = ?", Inquiry.status_div_id_by_key(:not_yet)])
    #プロジェクト
    @pending_approval_count = CmsProject.count_pending_approval(current_user.id)
    @pending_check_count = CmsProject.count_pending_check(current_user.id)
    #会員
    @member_count = User.count(:conditions => ["(test_flg IS NULL OR test_flg = 0) AND member_div = ?", User.member_div_id_by_key(:membership)])
    #売り上げ
    @today = Time.now()
    @this_month_sales = Order.count_at_term(@today.beginning_of_month, @today.end_of_month)
    @last_month_sales = Order.count_at_term(@today.last_month.beginning_of_month, @today.last_month.end_of_month)
    
    render(:dashboard)
  end
  
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/controllers/top_controller.rb <==
# -*- coding: utf-8 -*-
class TopController < ApplicationController  
  class_desc :display_name => "トップページ"

  desc :invisible => true, :auth => :user_login
  def index
    #ダッシュボードの表示権限がある場合はdashboardを表示する
    if Goldberg.action_authorised?('top', 'dashboard')
      dashboard
      return
    end
    
    render(:index)
  end
  
  desc :invisible => true, :auth => :user_login
  def action_authorised?
    logged_in?
  end
  
  # ダッシュボードを表示する
  desc :display_name => "ダッシュボード", :category_name => :index
  def dashboard
    #ダッシュボードの表示権限が無い場合はindexを表示する
    unless Goldberg.action_authorised?('top', 'dashboard')
      render(:index)
      return
    end
    
    #注文
    join_order_shippings = " JOIN order_shippings ON orders.id = order_shippings.order_id AND order_shippings.deleted_at IS NULL "
    #注文(特記事項なし)
    order_not_comment_counts = Order.count(:joins => join_order_shippings,
      :conditions => ["(test_flg IS NULL OR test_flg = 0) AND (free_request IS NULL OR free_request = '')"], :group => 'order_shippings.status_div')
    #注文(特記事項あり)
    @order_comment_counts = Order.count(:joins => join_order_shippings,
      :conditions => ["(test_flg IS NULL OR test_flg = 0) AND (free_request IS NOT NULL AND free_request != '')"], :group => 'order_shippings.status_div')
    #注文(特記事項あり＋特記事項なし)
    @order_counts = {}
    (order_not_comment_counts.keys+@order_comment_counts.keys).compact.each do |key|
      @order_counts[key] = order_not_comment_counts[key].to_i + @order_comment_counts[key].to_i
    end
    #問い合わせ
    @inquiry_count = Inquiry.count(:conditions => ["(test_flg IS NULL OR test_flg = 0) AND status_div = ?", Inquiry.status_div_id_by_key(:not_yet)])
    #プロジェクト
    @pending_approval_count = CmsProject.count_pending_approval(current_user.id)
    @pending_check_count = CmsProject.count_pending_check(current_user.id)
    #会員
    @member_count = User.count(:conditions => ["(test_flg IS NULL OR test_flg = 0) AND member_div = ?", User.member_div_id_by_key(:membership)])
    #売り上げ
    @today = Time.now()
    @this_month_sales = Order.count_at_term(@today.beginning_of_month, @today.end_of_month)
    @last_month_sales = Order.count_at_term(@today.last_month.beginning_of_month, @today.last_month.end_of_month)
    
    render(:dashboard)
  end
  
end
